<?php

namespace Mihanwp\FastCheckout\App\Controller;

use Mihanwp\FastCheckout\App\Core\Config;
use Mihanwp\FastCheckout\App\Model\Gateway as ModelGateway;
use Mihanwp\FastCheckout\App\Model\Product as ProductModel;

class Products
{
    static function addShortcodeValueMetabox()
    {
        add_meta_box('mw_fastcheckout_shortcode', __('Fast checkout shortcode', 'aani-woocommerce'), [__CLASS__, 'metaboxShortcodeValue'], null, 'side', 'high');
    }
    static function enqueueEditProductViewAssets($hookSuffix)
    {
        $screen = get_current_screen();
        $screenID = $screen ? $screen->id : false;
        if ($screenID === 'product') {
            $version = Config::get_plugin_version();
            wp_enqueue_style(
                'admin-fast-checkout',
                MW_AANI_CHECKOUT_DIR_URL . 'assets/css/admin/metabox-product-fast-checkout.css',
                null,
                $version,
            );
            wp_enqueue_script(
                'admin-fast-checkout',
                MW_AANI_CHECKOUT_DIR_URL . 'assets/js/admin/metabox-product-fast-checkout.js',
                ['jquery'],
                $version,
                true
            );
            $data = [
                'messages' => [
                    'copy_done' => __("It's copy", 'aani-woocommerce')
                ]
            ];
            wp_localize_script(
                'admin-fast-checkout',
                'mwfc_data',
                $data
            );
        }
    }
    static function metaboxShortcodeValue($post)
    {
        $availablePaymentGateways = ModelGateway::getAvailableGateways();
?>
        <p class="mwfc-shortcode-wrapper" dir="ltr">
            <span class="button button-primary" id="mwfc-shortcode-btn"><?php esc_html_e('Get shortcode', 'aani-woocommerce') ?></span>
        </p>
        <div class="mwfc-shortcode-modal-wrapper" pid="<?php echo esc_attr($post->ID)?>">
            <div class="content-box">
                <span class="close-btn dashicons dashicons-no"></span>
                <div class="form-wrapper">
                    <div id="short-code-value-wrapper"></div>
                    <div id="mwfc-notice-box"></div>
                    <div class="section-wrapper gateways">
                        <span class="section-title"><?php esc_html_e('Gateway', 'aani-woocommerce') ?></span>
                        <div class="fields-section check-box-view">
                            <?php if ($availablePaymentGateways) : ?>
                                <?php $counter = 0; foreach ($availablePaymentGateways as $key => $item) : $counter++;?>
                                    <div class="input-item checkbox-item">
                                        <label for="<?php echo esc_attr($key) ?>">
                                            <input <?php checked($counter, 1)?> type="radio" name="mwfc_form_gateway" id="<?php echo esc_attr($item->id) ?>" value="<?php echo esc_attr($item->id); ?>">
                                            <span class="input-value">
                                                <span class="icon"><?php echo wp_kses($item->get_icon(), ['img' => ['src' => true, 'alt' => true]]); ?></span>
                                                <span class="title"><?php echo esc_html($item->get_title()) ?></span>
                                            </span>
                                        </label>
                                    </div>
                                <?php endforeach; ?>
                            <?php else : ?>
                                <span><?php esc_html_e('No any available gateways found', 'aani-woocommerce') ?></span>
                            <?php endif; ?>
                        </div>
                    </div>
                    <div class="section-wrapper">
                        <span class="section-title"><label for="checkout_btn_text"><?php esc_html_e('Checkout button text', 'aani-woocommerce')?></label></span>
                        <div class="fields-section">
                            <div class="input-item">
                                <input type="text" value="<?php esc_html_e('Make payment', 'aani-woocommerce')?>" id="checkout_btn_text" name="checkout_btn_text">
                            </div>
                        </div>
                    </div>
                    <div class="section-wrapper">
                        <span class="section-title"><label for="invoice_amount_text_field"><?php esc_html_e('Description of the form', 'aani-woocommerce')?></label></span>
                        <div class="fields-section">
                            <div class="input-item">
                                <input type="text" value="<?php esc_html_e('Invoice payment amount', 'aani-woocommerce')?>" id="invoice_amount_text_field" name="invoice_amount_text_field">
                            </div>
                        </div>
                    </div>
                    <div class="section-wrapper">
                        <span class="section-title"><label for="order_qty_value"><?php esc_html_e('Quantity of product', 'aani-woocommerce')?></label></span>
                        <div class="fields-section">
                            <div class="input-item">
                                <input type="number" value="1" id="order_qty_value" name="order_qty_value">
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="modal-box"></div>
        </div>
<?php
    }

    static function addOnSaleEndTimeFieldToProductAdminView()
    {
        echo '<div id="sale_end_time_container" style="display:none;">';

        global $post;
        $value = ProductModel::getOnSaleEndTime($post->ID);

        woocommerce_wp_text_input(array(
            'id'          => '__aani_sale_end_time',
            'label'       => sprintf('%s (HH:MM:SS)', esc_html__('End of discount', 'aani-woocommerce')), //'ساعت پایان تخفیف (HH:MM:SS)',
            'desc_tip'    => true,
            'description' => sprintf(__('Just using in Aani Woocommerce', 'aani-woocommerce')),
            'type'        => 'time',
            'value' => esc_attr($value),
        ));
        echo '</div>';
    }
    static function handleSaveOnSaleEndTimeFieldValue($post_id)
    {
        if ( isset( $_POST['__aani_sale_end_time'] ) ) {
            ProductModel::setOnSaleEndTime($post_id, sanitize_text_field( $_POST['__aani_sale_end_time'] ));
        }
    }
}
