jQuery(document).ready(function ($) {
    let checkoutForm = $('form.aa-form-payment'),
        redirecting = false
    function notice(formWrapper, msg, type='error') {
        let noticeBox = formWrapper.find('.notice-box'),
            notice = $('<span>')
        notice.addClass(type)
        notice.text(msg)
        noticeBox.html(notice)
        setTimeout(() => {
            notice.remove()
        }, 2000);
    }
    function startCountDown(form)
    {
        let timerElement = form.find('.aa-timer'),
            endTime = parseInt(timerElement.attr('end-time-value')),
            serverTime = parseInt(timerElement.attr('server-time')),
            localTime = Math.floor(Date.now() / 1000),
            timeOffset = serverTime - localTime

        if(!endTime)
            return false

        function formatNumber(number)
        {
            return number < 10 ? '0' + number : number
        }
        function updateTimer() {
            var now = Math.floor(Date.now() / 1000) + timeOffset
            var timeLeft = endTime - now;

            if (timeLeft <= 0) {
                timerElement.html('<span>'+aani_data.messages.discount_end+'</span>');
                timerElement.closest('.aa-discount-section').find('.aa-discount-suffix').remove()
                clearInterval(timerInterval);
                return;
            }

            var days = Math.floor(timeLeft / (60 * 60 * 24));
            var hours = formatNumber(Math.floor((timeLeft % (60 * 60 * 24)) / (60 * 60)));
            var minutes = formatNumber(Math.floor((timeLeft % (60 * 60)) / 60));
            var seconds = formatNumber(timeLeft % 60);

            let timerText = ''
            if(days > 0)
            {
                timerText += days + " : "
            }
            timerText += hours + " : " + minutes + " : " + seconds

            timerElement.html(timerText)
        }

        var timerInterval = setInterval(updateTimer, 1000);
        updateTimer();
        
    }
    checkoutForm.each((index, value) => {
        let form = $(value),
            btn = form.find('.aa-payment-btn'),
            phoneNumber = form.find('input[name=phone-number]'),
            name = form.find('input[name=full-name]')
        form.on('submit', function (e) {
            e.preventDefault()
            if (!phoneNumber.val() || !name.val()) {
                notice(form, aani_data.messages.missing_field_value)
                return false;
            }
            btn.addClass('disabled');
            $.ajax({
                url: aani_data.au,
                type: 'post',
                dataType: 'json',
                data: {
                    action: 'mwfc_create_order_for_product',
                    nonce: form.attr('mwqp-nonce'),
                    qty: form.attr('mwqp-qty'),
                    pid: form.attr('pid'),
                    gateway: form.attr('gateway'),
                    phone: phoneNumber.val(),
                    name: name.val(),
                },
                success: response => {
                    let type = response.status === 'ok' ? 'success' : 'error'
                    if (response.msg) {
                        notice(form, response.msg, type)
                    }
                    if (response.status === 'ok') {
                        if (response.checkout_url) {
                            redirecting = true
                            notice(form, aani_data.messages.redirecting_to_payment_gateway, 'success')
                            window.location.href = response.checkout_url
                        }
                    }
                },
                error: err => {
                    notice(form, aani_data.messages.has_error_in_request)
                },
                complete: (xhr, status) => {
                    if(!redirecting)
                    {
                        btn.removeClass('disabled')
                    }
                }
            })
        })

        startCountDown(form)
    })
})